==> esp32s3-0.1.0.crate: esp32s3-0.1.0/src/pcnt/int_st.rs <==
#[doc = "Register `INT_ST` reader"]
pub struct R(crate::R<INT_ST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<INT_ST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<INT_ST_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<INT_ST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CNT_THR_EVENT_U0_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U0_INT interrupt."]
pub struct CNT_THR_EVENT_U0_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U0_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U0_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U0_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U1_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U1_INT interrupt."]
pub struct CNT_THR_EVENT_U1_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U1_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U1_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U1_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U2_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U2_INT interrupt."]
pub struct CNT_THR_EVENT_U2_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U2_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U2_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U2_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U3_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U3_INT interrupt."]
pub struct CNT_THR_EVENT_U3_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U3_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U3_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U3_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bit 0 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U0_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u0_int_st(&self) -> CNT_THR_EVENT_U0_INT_ST_R {
        CNT_THR_EVENT_U0_INT_ST_R::new((self.bits & 0x01) != 0)
    }
    #[doc = "Bit 1 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U1_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u1_int_st(&self) -> CNT_THR_EVENT_U1_INT_ST_R {
        CNT_THR_EVENT_U1_INT_ST_R::new(((self.bits >> 1) & 0x01) != 0)
    }
    #[doc = "Bit 2 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U2_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u2_int_st(&self) -> CNT_THR_EVENT_U2_INT_ST_R {
        CNT_THR_EVENT_U2_INT_ST_R::new(((self.bits >> 2) & 0x01) != 0)
    }
    #[doc = "Bit 3 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U3_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u3_int_st(&self) -> CNT_THR_EVENT_U3_INT_ST_R {
        CNT_THR_EVENT_U3_INT_ST_R::new(((self.bits >> 3) & 0x01) != 0)
    }
}
#[doc = "Interrupt status register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_st]
(index.html) module"]
pub struct INT_ST_SPEC;
impl crate::RegisterSpec for INT_ST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [int_st::R]
(R) reader structure"]
impl crate::Readable for INT_ST_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets INT_ST to value 0"]
impl crate::Resettable for INT_ST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32s3-0.2.0.crate: esp32s3-0.2.0/src/pcnt/int_st.rs <==
#[doc = "Register `INT_ST` reader"]
pub struct R(crate::R<INT_ST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<INT_ST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<INT_ST_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<INT_ST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CNT_THR_EVENT_U0_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U0_INT interrupt."]
pub struct CNT_THR_EVENT_U0_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U0_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U0_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U0_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U1_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U1_INT interrupt."]
pub struct CNT_THR_EVENT_U1_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U1_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U1_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U1_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U2_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U2_INT interrupt."]
pub struct CNT_THR_EVENT_U2_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U2_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U2_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U2_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CNT_THR_EVENT_U3_INT_ST` reader - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U3_INT interrupt."]
pub struct CNT_THR_EVENT_U3_INT_ST_R(crate::FieldReader<bool, bool>);
impl CNT_THR_EVENT_U3_INT_ST_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CNT_THR_EVENT_U3_INT_ST_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CNT_THR_EVENT_U3_INT_ST_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bit 0 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U0_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u0_int_st(&self) -> CNT_THR_EVENT_U0_INT_ST_R {
        CNT_THR_EVENT_U0_INT_ST_R::new((self.bits & 1) != 0)
    }
    #[doc = "Bit 1 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U1_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u1_int_st(&self) -> CNT_THR_EVENT_U1_INT_ST_R {
        CNT_THR_EVENT_U1_INT_ST_R::new(((self.bits >> 1) & 1) != 0)
    }
    #[doc = "Bit 2 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U2_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u2_int_st(&self) -> CNT_THR_EVENT_U2_INT_ST_R {
        CNT_THR_EVENT_U2_INT_ST_R::new(((self.bits >> 2) & 1) != 0)
    }
    #[doc = "Bit 3 - The masked interrupt status bit for the PCNT_CNT_THR_EVENT_U3_INT interrupt."]
    #[inline(always)]
    pub fn cnt_thr_event_u3_int_st(&self) -> CNT_THR_EVENT_U3_INT_ST_R {
        CNT_THR_EVENT_U3_INT_ST_R::new(((self.bits >> 3) & 1) != 0)
    }
}
#[doc = "Interrupt status register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_st]
(index.html) module"]
pub struct INT_ST_SPEC;
impl crate::RegisterSpec for INT_ST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [int_st::R]
(R) reader structure"]
impl crate::Readable for INT_ST_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets INT_ST to value 0"]
impl crate::Resettable for INT_ST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
